@@ -33,6 +33,8 @@ void aboutWindow (GtkWidget *widget, gpointer data)
 	GtkWidget *label2;
 	GtkWidget *author;
 	GtkWidget *email;
+	GtkWidget *author2;
+	GtkWidget *email2;
 	char *versionString;
 
 	versionString = (char*)malloc(sizeof(char)*100);
@@ -46,6 +48,8 @@ void aboutWindow (GtkWidget *widget, gpointer data)
 	label2 = gtk_label_new(versionString);
 	author = gtk_label_new("Pascal Jermini");
 	email = gtk_label_new("lorelei@garage.maemo.org");
+	author2 = gtk_label_new("Geert Steyaert");
+	email2 = gtk_label_new("geert.steyaert@gmail.com");
 
 	
 	vbox = gtk_vbox_new (FALSE, 0);
@@ -53,6 +57,8 @@ void aboutWindow (GtkWidget *widget, gpointer data)
 	gtk_box_pack_start (GTK_BOX (vbox), label2, FALSE, FALSE, 0); 
 	gtk_box_pack_start (GTK_BOX (vbox), author, FALSE, FALSE, 10); 
 	gtk_box_pack_start (GTK_BOX (vbox), email, FALSE, FALSE, 0); 
+	gtk_box_pack_start (GTK_BOX (vbox), author2, FALSE, FALSE, 10); 
+	gtk_box_pack_start (GTK_BOX (vbox), email2, FALSE, FALSE, 0); 
 	gtk_container_add (GTK_CONTAINER (win), vbox);
 
 	/* This call show the window and also add the window to the stack */
