@@ -111,7 +111,7 @@ static void vpnConnect (GtkWidget *widget, gpointer   data)
 	gint fout, ferr,argc;
 	gchar *command;
 	gchar **argv;
-	gchar *profile = NULL, *username, *password, *server;
+	gchar *profile = NULL, *username, *password, *server, *free_option;
 	OpenConnectGUI *self = (OpenConnectGUI*)data;
 
 	profile = hildon_touch_selector_get_current_text(HILDON_TOUCH_SELECTOR(self->profileSelector));
@@ -127,14 +127,18 @@ static void vpnConnect (GtkWidget *widget, gpointer   data)
 	username = g_key_file_get_string(self->keyfile, profile, "username", NULL);
 	password = g_key_file_get_string(self->keyfile, profile, "password", NULL);
 	server = g_key_file_get_string(self->keyfile, profile, "server", NULL);
+	free_option = g_key_file_get_string(self->keyfile, profile, "free_option", NULL);
+
 
 #ifdef DEBUG
-	command = g_strdup_printf("./openconnect-wrapper --user=%s --passwd=%s %s", username, password, server);
+	command = g_strdup_printf("./openconnect-wrapper --user=%s --passwd=\"%s\" %s %s", username, password, free_option, server);
 #else
-	command = g_strdup_printf("/usr/bin/openconnect-wrapper --user=%s --passwd=%s %s", username, password, server);
+	command = g_strdup_printf("/usr/bin/openconnect-wrapper --user=%s --passwd=\"%s\" %s %s", username, password, free_option, server);
 #endif
 	g_shell_parse_argv(command, &argc, &argv, NULL);
 
+//    write_log_line(command, self, FALSE);
+
 	g_spawn_async_with_pipes (NULL, argv, NULL, G_SPAWN_SEARCH_PATH, 
 			NULL, NULL, &(self->pid), NULL, &fout, &ferr, NULL);
 
