@@ -53,9 +53,11 @@ int main(int argc, char *argv[]) {
 			exit(1);
 		}
 #ifdef DEBUG
-		execl("./senseless", "openconnect", "--script=/usr/share/openconnect/vpnc-script", argv[1], argv[2], argv[3], NULL);
+		execl("./senseless", "openconnect", "--script=/usr/share/openconnect/vpnc-script", "--no-dtls", 
+			"--no-cert-check", argv[1], argv[2], argv[3], argv[4], NULL);
 #else
-		execl("/usr/bin/openconnect", "openconnect", "--script=/usr/share/openconnect/vpnc-script", argv[1], argv[2], argv[3], NULL);
+		execl("/usr/bin/openconnect", "openconnect", "--script=/usr/share/openconnect/vpnc-script", "--no-dtls", 
+			"--no-cert-check", argv[1], argv[2], argv[3], argv[4], NULL);
 #endif
 	}
 	else {
