@@ -26,7 +26,7 @@
 
 void saveProfile_cb (GtkWidget *widget, gpointer data)
 {
-	const gchar *profileName, *server, *username, *password;
+	const gchar *profileName, *server, *username, *password, *free_option;
 	profileWidgets *self = (profileWidgets*)data;
 	gchar *sdata;
 	gsize confSize;
@@ -35,6 +35,7 @@ void saveProfile_cb (GtkWidget *widget, gpointer data)
 	server = hildon_entry_get_text(HILDON_ENTRY(self->server));
 	username = hildon_entry_get_text(HILDON_ENTRY(self->username));
 	password = hildon_entry_get_text(HILDON_ENTRY(self->password));
+	free_option = hildon_entry_get_text(HILDON_ENTRY(self->free_option));
 
 	if ((g_strcmp0(profileName, "") == 0) ||
 					(g_strcmp0(server, "") == 0) ||
@@ -57,6 +58,7 @@ void saveProfile_cb (GtkWidget *widget, gpointer data)
 	g_key_file_set_string(self->appData->keyfile, profileName, "server", server);
 	g_key_file_set_string(self->appData->keyfile, profileName, "username", username);
 	g_key_file_set_string(self->appData->keyfile, profileName, "password", password);
+	g_key_file_set_string(self->appData->keyfile, profileName, "free_option", free_option);
 
 	sdata = g_key_file_to_data (self->appData->keyfile, &confSize, NULL);
 	/* XXX error checking! */
@@ -74,10 +76,10 @@ profileWidgets *createProfilesWindow (GtkWidget *widget, gpointer data)
 	profileWidgets *self;
 	OpenConnectGUI *rootData = (OpenConnectGUI*)data;
 
-	GtkWidget *vbox, *profNameBox, *serverBox, *usernameBox, *passwordBox;
+	GtkWidget *vbox, *profNameBox, *serverBox, *usernameBox, *passwordBox, *free_optionBox;
 	GtkWidget *buttonBox, *saveButton;
 	GtkWidget *profileNameLabel, *serverLabel, *usernameLabel, 
-		  *passwordLabel;
+		  *passwordLabel, *free_optionLabel;
 	self = (profileWidgets*)malloc(sizeof(profileWidgets));
 	self->appData = rootData;
 	self->editingProfile = FALSE;
@@ -104,13 +106,17 @@ profileWidgets *createProfilesWindow (GtkWidget *widget, gpointer data)
 	self->password = hildon_entry_new(HILDON_SIZE_HALFSCREEN_WIDTH);
 	hildon_gtk_entry_set_input_mode(GTK_ENTRY(self->password), HILDON_GTK_INPUT_MODE_FULL | !HILDON_GTK_INPUT_MODE_AUTOCAP);
 	gtk_entry_set_visibility(GTK_ENTRY(self->password), FALSE);
-
+	free_optionLabel = gtk_label_new("Free option");
+	gtk_misc_set_alignment(GTK_MISC(free_optionLabel), 1.0, 0.5);
+	self->free_option = hildon_entry_new(HILDON_SIZE_HALFSCREEN_WIDTH);
+	hildon_gtk_entry_set_input_mode(GTK_ENTRY(self->free_option), HILDON_GTK_INPUT_MODE_FULL | !HILDON_GTK_INPUT_MODE_AUTOCAP);
 	
 	vbox = gtk_vbox_new (FALSE, 0);
 	profNameBox = gtk_hbox_new (FALSE, 0);
 	serverBox = gtk_hbox_new (FALSE, 0);
 	usernameBox = gtk_hbox_new (FALSE, 0);
 	passwordBox = gtk_hbox_new (FALSE, 0);
+    free_optionBox =  gtk_hbox_new (FALSE, 0);
 	buttonBox = gtk_hbox_new (FALSE, 0);
 
 	gtk_box_pack_start (GTK_BOX(profNameBox), profileNameLabel, TRUE, 
@@ -129,6 +135,10 @@ profileWidgets *createProfilesWindow (GtkWidget *widget, gpointer data)
 			TRUE, 0); 
 	gtk_box_pack_start (GTK_BOX(passwordBox), self->password, TRUE, 
 			FALSE, 0); 
+	gtk_box_pack_start (GTK_BOX(free_optionBox), free_optionLabel, TRUE, 
+			TRUE, 0); 
+	gtk_box_pack_start (GTK_BOX(free_optionBox), self->free_option, TRUE, 
+			FALSE, 0); 
 
 	saveButton = hildon_button_new_with_text (HILDON_SIZE_FINGER_HEIGHT, 
 			HILDON_BUTTON_ARRANGEMENT_HORIZONTAL, "Save", 
@@ -144,6 +154,7 @@ profileWidgets *createProfilesWindow (GtkWidget *widget, gpointer data)
 	gtk_box_pack_start(GTK_BOX(vbox), serverBox, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), usernameBox, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), passwordBox, FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(vbox), free_optionBox, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), buttonBox, FALSE, FALSE, 0);
 	
 	gtk_container_add(GTK_CONTAINER(self->win), vbox);
@@ -157,7 +168,7 @@ profileWidgets *createProfilesWindow (GtkWidget *widget, gpointer data)
 
 void editProfile (gpointer data, gchar* profile)
 {
-   gchar *username, *password, *server;
+   gchar *username, *password, *server, *free_option;
 	profileWidgets *self = (profileWidgets*)data;
 	self->editingProfile = TRUE;
 	self->oldName = g_strdup(profile);
@@ -165,11 +176,13 @@ void editProfile (gpointer data, gchar* profile)
 	username = g_key_file_get_string(self->appData->keyfile, profile, "username", NULL);
 	password = g_key_file_get_string(self->appData->keyfile, profile, "password", NULL);
 	server = g_key_file_get_string(self->appData->keyfile, profile, "server", NULL);
+	free_option = g_key_file_get_string(self->appData->keyfile, profile, "free_option", NULL);
 
 	hildon_entry_set_text(HILDON_ENTRY(self->profileName), profile);
 	hildon_entry_set_text(HILDON_ENTRY(self->server), server);
 	hildon_entry_set_text(HILDON_ENTRY(self->username), username);
 	hildon_entry_set_text(HILDON_ENTRY(self->password), password);
+	hildon_entry_set_text(HILDON_ENTRY(self->free_option), free_option);
 
 }
 
